@@ -85,12 +85,14 @@ LockFrame::LockFrame(SessionBaseModel *const model, QWidget *parent)
     connect(m_lockContent, &LockContent::requestStartAuthentication, this, &LockFrame::requestStartAuthentication);
     connect(m_lockContent, &LockContent::sendTokenToAuth, this, &LockFrame::sendTokenToAuth);
     connect(m_lockContent, &LockContent::requestEndAuthentication, this, &LockFrame::requestEndAuthentication);
+    connect(m_lockContent, &LockContent::requestLockFrameHide, this, [this] {
+        m_model->setVisible(false);
+    });
     connect(m_lockContent, &LockContent::authFinished, this, [this] {
-        hide();
+        m_model->setVisible(false);
         emit requestEnableHotzone(true);
         emit authFinished();
     });
-    connect(model, &SessionBaseModel::blackModeChanged, this, &FullscreenBackground::setIsBlackMode);
     connect(model, &SessionBaseModel::showUserList, this, &LockFrame::showUserList);
     connect(model, &SessionBaseModel::showLockScreen, this, &LockFrame::showLockScreen);
     connect(model, &SessionBaseModel::showShutdown, this, &LockFrame::showShutdown);
@@ -108,15 +110,15 @@ LockFrame::LockFrame(SessionBaseModel *const model, QWidget *parent)
         }
 
         //待机时由锁屏提供假黑屏，唤醒时显示正常界面
-        model->setVisible(true);
         model->setIsBlackMode(isSleep);
+        model->setVisible(true);
 
         if (!isSleep) {
             //待机唤醒后检查是否需要密码，若不需要密码直接隐藏锁定界面
             if (QGSettings::isSchemaInstalled("com.deepin.dde.power")) {
                 QGSettings powerSettings("com.deepin.dde.power", QByteArray(), this);
                 if (!powerSettings.get("sleep-lock").toBool()) {
-                    hide();
+                    m_model->setVisible(false);
                 }
             }
         }
@@ -125,7 +127,7 @@ LockFrame::LockFrame(SessionBaseModel *const model, QWidget *parent)
     connect(model, &SessionBaseModel::authFinished, this, [this](bool success) {
         if (success) {
             Q_EMIT requestEnableHotzone(true);
-            hide();
+            m_model->setVisible(false);
         }
     });
 
@@ -134,7 +136,7 @@ LockFrame::LockFrame(SessionBaseModel *const model, QWidget *parent)
         m_enablePowerOffKey = true;
     });
 
-    if (getDConfigValue(getDefaultConfigFileName(), "auto-exit", false).toBool()) {
+    if (getDConfigValue(getDefaultConfigFileName(), "autoExit", false).toBool()) {
         m_autoExitTimer = new QTimer(this);
         m_autoExitTimer->setInterval(1000*60); //1分钟
         m_autoExitTimer->setSingleShot(true);
@@ -243,20 +245,20 @@ void LockFrame::showUserList()
 {
     m_model->setCurrentModeState(SessionBaseModel::ModeStatus::UserMode);
     QTimer::singleShot(10, this, [ = ] {
-        this->show();
+        m_model->setVisible(true);
     });
 }
 
 void LockFrame::showLockScreen()
 {
     m_model->setCurrentModeState(SessionBaseModel::ModeStatus::PasswordMode);
-    show();
+    m_model->setVisible(true);
 }
 
 void LockFrame::showShutdown()
 {
     m_model->setCurrentModeState(SessionBaseModel::ModeStatus::ShutDownMode);
-    show();
+    m_model->setVisible(true);
 }
 
 void LockFrame::shutdownInhibit(const SessionBaseModel::PowerAction action, bool needConfirm)
@@ -317,7 +319,6 @@ void LockFrame::showEvent(QShowEvent *event)
 {
     emit requestEnableHotzone(false);
 
-    m_model->setVisible(true);
     if (m_autoExitTimer)
         m_autoExitTimer->stop();
 
@@ -328,7 +329,6 @@ void LockFrame::hideEvent(QHideEvent *event)
 {
     emit requestEnableHotzone(true);
 
-    m_model->setVisible(false);
     if (m_autoExitTimer)
         m_autoExitTimer->start();
 
