@@ -151,6 +151,7 @@ void LockWorker::initConnections()
             endAuthentication(m_account, AT_All);
             destoryAuthentication(m_model->currentUser()->name());
             setCurrentUser(m_model->currentUser());
+            setLocked(false);
         }
     });
     connect(m_model, &SessionBaseModel::onStatusChanged, this, [=](SessionBaseModel::ModeStatus state) {
@@ -446,13 +447,7 @@ void LockWorker::switchToUser(std::shared_ptr<User> user)
     qDebug() << "LockWorker::switchToUser:" << m_account << user->name();
     if (user->name() == m_account || *user == *m_model->currentUser()) {
         qInfo() << "switch to current user:" << user->name() << user->isLogin();
-        if (!m_authFramework->authSessionExist(m_account)) {
-            createAuthentication(user->name());
-        } else {
-            endAuthentication(m_account, AT_All);
-            destoryAuthentication(m_account);
-            createAuthentication(m_account);
-        }
+        createAuthentication(user->name());
         return;
     } else {
         qInfo() << "switch user from" << m_account << "to" << user->name() << user->isLogin();
@@ -520,6 +515,12 @@ void LockWorker::createAuthentication(const QString &account)
         return;
     }
 
+    // 如果验证会话已经存在，销毁后重新开启验证
+    if (m_authFramework->authSessionExist(account)) {
+        endAuthentication(account, AT_All);
+        destoryAuthentication(account);
+    }
+
     // 同步密码过期的信息
     std::shared_ptr<User> user_ptr = m_model->findUserByName(account);
     if (user_ptr) {
@@ -616,6 +617,14 @@ void LockWorker::endAuthentication(const QString &account, const int authType)
     }
 }
 
+void LockWorker::onEndAuthentication(const QString &account, const int authType)
+{
+    endAuthentication(account, authType);
+    if (AT_All == authType) {
+        destoryAuthentication(account);
+    }
+}
+
 void LockWorker::lockServiceEvent(quint32 eventType, quint32 pid, const QString &username, const QString &message)
 {
     Q_UNUSED(pid)
