@@ -23,17 +23,21 @@ public:
     void register_for_mutil_screen(std::function<QWidget* (QScreen *, int)> function);
     void startRaiseContentFrame();
 
+protected:
+    bool eventFilter(QObject *watched, QEvent *event) override;
+
 private:
-    void onScreenAdded(QScreen *screen);
-    void onScreenRemoved(QScreen *screen);
+    void onScreenAdded(QPointer<QScreen> screen);
+    void onScreenRemoved(QPointer<QScreen> screen);
     void raiseContentFrame();
     int getDisplayModeByConfig(const QString &config) const;
 
 private slots:
     void onDisplayModeChanged(const QString &);
+    void checkLockFrameLocation();
 
 private:
-    std::function<QWidget* (QScreen *, int)> m_registerFunction;
+    std::function<QWidget* (QPointer<QScreen> , int)> m_registerFunction;
     QMap<QScreen*, QWidget*> m_frames;
     QTimer *m_raiseContentFrameTimer;
     SystemDisplayInter *m_systemDisplay;
