@@ -10,6 +10,7 @@
 
 #include <com_deepin_system_systempower.h>
 #include <pwd.h>
+#include </usr/include/shadow.h>
 
 #define LOCKSERVICE_PATH "/com/deepin/dde/LockService"
 #define LOCKSERVICE_NAME "com.deepin.dde.LockService"
@@ -197,10 +198,17 @@ void GreeterWorker::initConnections()
             m_resetSessionTimer->stop();
         }
     });
-    /* others */
+    /* 数字键盘状态 */
     connect(KeyboardMonitor::instance(), &KeyboardMonitor::numlockStatusChanged, this, [=](bool on) {
         saveNumlockState(m_model->currentUser(), on);
     });
+
+    connect(KeyboardMonitor::instance(), &KeyboardMonitor::initialized, this, [this] {
+        if (m_model) {
+            recoveryUserKBState(m_model->currentUser());
+        }
+    });
+
     connect(m_limitsUpdateTimer, &QTimer::timeout, this, [this] {
         if (m_authFramework->isDeepinAuthValid())
             m_model->updateLimitedInfo(m_authFramework->GetLimitedInfo(m_account));
@@ -228,10 +236,11 @@ void GreeterWorker::initData()
 
     /* init current user */
     if (DSysInfo::deepinType() == DSysInfo::DeepinServer || m_model->allowShowCustomUser()) {
+        // 如果是服务器版本或者loginPromptInput配置为true，默认显示空用户
         std::shared_ptr<User> user(new User());
         m_model->setIsServerModel(DSysInfo::deepinType() == DSysInfo::DeepinServer);
         m_model->addUser(user);
-        if (DSysInfo::deepinType() == DSysInfo::DeepinServer) {
+        if (DSysInfo::deepinType() == DSysInfo::DeepinServer || valueByQSettings<bool>("", "loginPromptInput", false)) {
             m_model->updateCurrentUser(user);
         } else {
             /* com.deepin.dde.LockService */
@@ -381,7 +390,49 @@ void GreeterWorker::createAuthentication(const QString &account)
     std::shared_ptr<User> user_ptr = m_model->findUserByName(account);
     if (user_ptr) {
         user_ptr->updatePasswordExpiredInfo();
+    } else {
+        // 域管账户第一次登录时，后端还未提供账户信息，获取不到用户密码过期数据
+        // 需要通过glibc接口读取
+        std::string str = account.toStdString();
+        spwd *pw = getspnam(str.c_str());
+
+        if (pw) {
+            const int secondsPerDay = 60 * 60 * 24;
+
+            long int spMax = pw->sp_max;
+            long int spWarn = pw->sp_warn;
+            long int spLastChg = pw->sp_lstchg;
+
+            User::ExpiredState state = User::ExpiredNormal;
+            int days = 0;
+
+            if (spLastChg == 0) {
+                // expired
+                state = User::ExpiredAlready;
+                days = 0;
+            }
+
+            if (spMax == -1) {
+                // never expired
+                state = User::ExpiredNormal;
+                days = -1;
+            }
+
+            int curDays = QDateTime::currentDateTime().time().msec() / secondsPerDay;
+            int daysLeft = spLastChg + spMax - curDays;
+
+            if (daysLeft < 0) {
+                state = User::ExpiredAlready;
+                days = daysLeft;
+            } else if (spWarn > daysLeft) {
+                state = User::ExpiredSoon;
+                days = daysLeft;
+            }
+
+            m_model->currentUser()->updatePasswordExpiredState(state, days);
+        }
     }
+
     switch (m_model->getAuthProperty().FrameworkState) {
     case Available:
         m_authFramework->CreateAuthController(account, m_authFramework->GetSupportedMixAuthFlags(), Login);
@@ -816,10 +867,6 @@ int GreeterWorker::getNumLockState(const QString &userName)
 
 void GreeterWorker::recoveryUserKBState(std::shared_ptr<User> user)
 {
-    //FIXME(lxz)
-    //    PowerInter powerInter("com.deepin.system.Power", "/com/deepin/system/Power", QDBusConnection::systemBus(), this);
-    //    const BatteryPresentInfo info = powerInter.batteryIsPresent();
-    //    const bool defaultValue = !info.values().first();
     if (user.get() == nullptr)
         return;
 
@@ -828,9 +875,11 @@ void GreeterWorker::recoveryUserKBState(std::shared_ptr<User> user)
     qWarning() << "restore numlock state to " << enabled;
 
     // Resync numlock light with numlock status
-    bool cur_numlock = KeyboardMonitor::instance()->isNumlockOn();
-    KeyboardMonitor::instance()->setNumlockStatus(!cur_numlock);
-    KeyboardMonitor::instance()->setNumlockStatus(cur_numlock);
+    if (!m_model->isUseWayland()) {
+        bool cur_numlock = KeyboardMonitor::instance()->isNumlockOn();
+        KeyboardMonitor::instance()->setNumlockStatus(!cur_numlock);
+        KeyboardMonitor::instance()->setNumlockStatus(cur_numlock);
+    }
 
     KeyboardMonitor::instance()->setNumlockStatus(enabled);
 }
