@@ -99,6 +99,7 @@ void AuthPassword::initUI()
 
     /* 认证状态 */
     m_authStateLabel = new DLabel(this);
+    m_authStateLabel->setVisible(false);
     setAuthStateStyle(LOGIN_WAIT);
     passwordLayout->addWidget(m_authStateLabel, 0, Qt::AlignRight | Qt::AlignVCenter);
     /* 密码提示 */
@@ -109,6 +110,7 @@ void AuthPassword::initUI()
     m_passwordHintBtn->setFlat(true);
     m_passwordHintBtn->setIcon(QIcon(PASSWORD_HINT));
     m_passwordHintBtn->setIconSize(QSize(16, 16));
+    m_passwordHintBtn->setVisible(false);
     passwordLayout->addWidget(m_passwordHintBtn, 0, Qt::AlignRight | Qt::AlignVCenter);
 
     mainLayout->addWidget(m_lineEdit);
@@ -124,7 +126,8 @@ void AuthPassword::initConnections()
     connect(m_passwordHintBtn, &DIconButton::clicked, this, &AuthPassword::showPasswordHint);
     /* 密码输入框 */
     connect(m_lineEdit, &DLineEditEx::focusChanged, this, [this](const bool focus) {
-        if (!focus) m_lineEdit->setAlert(false);
+        if (!focus)
+            m_lineEdit->setAlert(false);
         m_authStateLabel->setVisible(!focus && m_showAuthState);
         emit focusChanged(focus);
     });
@@ -463,9 +466,6 @@ void AuthPassword::showResetPasswordMessage()
     m_resetPasswordFloatingMessage->setWidget(suggestButton);
     m_resetPasswordFloatingMessage->setMessage(tr("Forgot password?"));
     connect(suggestButton, &QPushButton::clicked, this, [ this ] {
-        if (window()->windowHandle() && window()->windowHandle()->setKeyboardGrabEnabled(false)) {
-            qDebug() << "setKeyboardGrabEnabled(false) success!";
-        }
         const QString AccountsService("com.deepin.daemon.Accounts");
         const QString path = QString("/com/deepin/daemon/Accounts/User%1").arg(m_currentUid);
         com::deepin::daemon::accounts::User user(AccountsService, path, QDBusConnection::systemBus());
@@ -601,3 +601,9 @@ void AuthPassword::hideEvent(QHideEvent *event)
     closeResetPasswordMessage();
     AuthModule::hideEvent(event);
 }
+
+void AuthPassword::setAuthStatueVisible(bool visible)
+{
+    m_showAuthState = visible;
+    m_authStateLabel->setVisible(visible && !hasFocus());
+}
