@@ -72,6 +72,7 @@ void AuthUKey::initUI()
     UKeyLayout->addWidget(m_capsLock, 0, Qt::AlignRight | Qt::AlignVCenter);
     /* 认证状态 */
     m_authStateLabel = new DLabel(m_lineEdit);
+    m_authStateLabel->setVisible(false);
     setAuthStateStyle(LOGIN_WAIT);
     UKeyLayout->addWidget(m_authStateLabel, 0, Qt::AlignRight | Qt::AlignVCenter);
 
@@ -87,7 +88,7 @@ void AuthUKey::initConnections()
     /* PIN 码输入框 */
     connect(m_lineEdit, &DLineEditEx::focusChanged, this, [this](const bool focus) {
         if (!focus) m_lineEdit->setAlert(false);
-        m_authStateLabel->setVisible(!focus);
+        m_authStateLabel->setVisible(!focus && m_showAuthState);
         emit focusChanged(focus);
     });
     connect(m_lineEdit, &DLineEditEx::textChanged, this, [this](const QString &text) {
@@ -347,3 +348,9 @@ void AuthUKey::hide()
     setLineEditInfo(tr("Enter your PIN"), PlaceHolderText);
     AuthModule::hide();
 }
+
+void AuthUKey::setAuthStatueVisible(bool visible)
+{
+    m_showAuthState = visible;
+    m_authStateLabel->setVisible(visible && !hasFocus());
+}
\ No newline at end of file
