@@ -16,12 +16,21 @@ SessionBaseModel::SessionBaseModel(QObject *parent)
     , m_visible(false)
     , m_isServerModel(false)
     , m_canSleep(false)
+    , m_allowShowUserSwitchButton(false)
+    , m_alwaysShowUserSwitchButton(false)
+    , m_abortConfirm(false)
     , m_isLockNoPassword(false)
+    , m_isBlackMode(false)
+    , m_isHibernateMode(false)
+    , m_allowShowCustomUser(false)
     , m_SEOpen(false)
+    , m_isUseWayland(QGuiApplication::platformName().startsWith("wayland", Qt::CaseInsensitive))
     , m_appType(AuthCommon::None)
     , m_currentUser(nullptr)
+    , m_lastLogoutUser(nullptr)
     , m_powerAction(PowerAction::RequireNormal)
     , m_currentModeState(ModeStatus::NoStatus)
+    , m_authProperty {false, false, Unavailable, AuthCommon::None, AuthCommon::None, 0, "", "", ""}
     , m_users(new QMap<QString, std::shared_ptr<User>>())
     , m_loginedUsers(new QMap<QString, std::shared_ptr<User>>())
 {
@@ -320,59 +329,75 @@ void SessionBaseModel::removeUser(const std::shared_ptr<User> user)
 }
 
 /**
- * @brief 保存当前用户信息
+ * @brief json数据转成user对象
  *
  * @param userJson
  */
-void SessionBaseModel::updateCurrentUser(const QString &userJson)
+std::shared_ptr<User> SessionBaseModel::json2User(const QString &userJson)
 {
-    qDebug("update current user, data: %s", qPrintable(userJson));
+    qDebug("user json data: %s", qPrintable(userJson));
 
     std::shared_ptr<User> user_ptr;
     QJsonParseError jsonParseError;
     const QJsonDocument userDoc = QJsonDocument::fromJson(userJson.toUtf8(), &jsonParseError);
     if (jsonParseError.error != QJsonParseError::NoError || userDoc.isEmpty()) {
         qWarning("failed to obtain current user information from LockService!");
-        user_ptr = m_lastLogoutUser ? m_lastLogoutUser : m_users->first();
-    } else {
-        const QJsonObject userObj = userDoc.object();
-        const QString &name = userObj["Name"].toString();
-        user_ptr = findUserByName(name);
-        if (name.isEmpty() || user_ptr == nullptr) {
-            const uid_t uid = static_cast<uid_t>(userObj["Uid"].toInt());
-            user_ptr = findUserByUid(uid);
-        }
-        if (user_ptr == nullptr) {
-            qWarning("failed to find user!");
-            user_ptr = m_lastLogoutUser ? m_lastLogoutUser : m_users->first();
-        }
-        if (user_ptr) {
-            user_ptr->setLastAuthType(userObj["AuthType"].toInt());
-        }
+        return user_ptr;
     }
-    updateCurrentUser(user_ptr);
+
+    const QJsonObject userObj = userDoc.object();
+    const QString &name = userObj["Name"].toString();
+    user_ptr = findUserByName(name);
+    if (name.isEmpty() || user_ptr == nullptr) {
+        const uid_t uid = static_cast<uid_t>(userObj["Uid"].toInt());
+        user_ptr = findUserByUid(uid);
+    }
+    if (user_ptr)
+        user_ptr->setLastAuthType(userObj["AuthType"].toInt());
+
+    return user_ptr;
+}
+
+/**
+ * @brief 保存当前用户信息
+ *
+ * @param userJson
+ * @return 是否更新了用户
+ */
+bool SessionBaseModel::updateCurrentUser(const QString &userJson)
+{
+    qDebug("update current user, data: %s", qPrintable(userJson));
+
+    std::shared_ptr<User> user_ptr = json2User(userJson);
+    if (!user_ptr)
+        user_ptr = m_lastLogoutUser ? m_lastLogoutUser : m_users->first();
+
+    return updateCurrentUser(user_ptr);
 }
 
 /**
  * @brief 保存当前用户信息
  *
  * @param user
+ * @return 是否更新了用户
  */
-void SessionBaseModel::updateCurrentUser(const std::shared_ptr<User> user)
+bool SessionBaseModel::updateCurrentUser(const std::shared_ptr<User> user)
 {
     if (!user) {
         qWarning() << "Failed to set current user!" << user.get();
-        return;
+        return false;
     }
 
     qDebug() << "SessionBaseModel::updateCurrentUser:" << user->name();
 
     if (m_currentUser && *m_currentUser == *user) {
-        return;
+        return false;
     }
 
     m_currentUser = user;
     emit currentUserChanged(user);
+
+    return true;
 }
 
 /**
@@ -406,13 +431,13 @@ void SessionBaseModel::updateUserList(const QStringList &list)
  */
 void SessionBaseModel::updateLastLogoutUser(const uid_t uid)
 {
-    qDebug("update logout user, id: %d", uid);
-
-    for (const std::shared_ptr<User> &user : m_users->values()) {
-        if (uid == user->uid()) {
-            updateLastLogoutUser(user);
-            break;
-        }
+    qDebug() << "SessionBaseModel::updateLastLogoutUser:" << uid;
+    QList<std::shared_ptr<User>> userList = m_users->values();
+    auto it = std::find_if(userList.begin(), userList.end(), [uid](std::shared_ptr<User> &user) {
+        return user->uid() == uid;
+    });
+    if (it != userList.end()) {
+        updateLastLogoutUser(it.i->t());
     }
 }
 
@@ -423,11 +448,11 @@ void SessionBaseModel::updateLastLogoutUser(const uid_t uid)
  */
 void SessionBaseModel::updateLastLogoutUser(const std::shared_ptr<User> lastLogoutUser)
 {
-    qDebug("update logout user, name: %s, id: %d", qPrintable(lastLogoutUser->name()), lastLogoutUser->uid());
-
-    if (m_lastLogoutUser && m_lastLogoutUser == lastLogoutUser) {
+    if (!lastLogoutUser.get() || m_lastLogoutUser == lastLogoutUser) {
         return;
     }
+    qInfo() << "last logout user:" << lastLogoutUser->name() << lastLogoutUser->uid();
+
     m_lastLogoutUser = lastLogoutUser;
 }
 
@@ -616,16 +641,16 @@ void SessionBaseModel::updateFactorsInfo(const MFAInfoList &infoList)
  * @param state
  * @param result
  */
-void SessionBaseModel::updateAuthState(const int type, const int state, const QString &result)
+void SessionBaseModel::updateAuthState(const int type, const int state, const QString &message)
 {
-    qDebug("update auth state, type: %d, state: %d, result: %s", type, state, qPrintable(result));
+    qDebug("update auth state, type: %d, state: %d, result: %s", type, state, qPrintable(message));
 
     switch (m_authProperty.FrameworkState) {
     case Available:
-        emit authStateChanged(type, state, result);
+        emit authStateChanged(type, state, message);
         break;
     default:
-        emit authStateChanged(AT_PAM, state, result);
+        emit authStateChanged(AT_PAM, state, message);
         break;
     }
 }
