@@ -51,15 +51,15 @@ public:
 
     /* com.deepin.daemon.Authenticate */
     struct AuthProperty {
-        bool FuzzyMFA;                        // Reserved
-        bool MFAFlag = false;                 // 多因子标志位
-        int FrameworkState = Unavailable;     // 认证框架是否可用标志位
-        int AuthType = 0;                     // 账户开启的认证类型
-        int MixAuthFlags;                     // 受支持的认证类型
-        int PINLen = 0;                       // PIN 码的最大长度
-        QString EncryptionType;               // 加密类型
-        QString Prompt;                       // 提示语
-        QString UserName;                     // 账户名
+        bool FuzzyMFA;          // Reserved
+        bool MFAFlag;           // 多因子标志位
+        int FrameworkState;     // 认证框架是否可用标志位
+        int AuthType;           // 账户开启的认证类型
+        int MixAuthFlags;       // 受支持的认证类型
+        int PINLen;             // PIN 码的最大长度
+        QString EncryptionType; // 加密类型
+        QString Prompt;         // 提示语
+        QString UserName;       // 账户名
     };
 
     explicit SessionBaseModel(QObject *parent = nullptr);
@@ -97,6 +97,8 @@ public:
     void setHasSwap(bool hasSwap);
     inline bool hasSwap() { return m_hasSwap; }
 
+    inline bool isUseWayland() const { return m_isUseWayland; }
+
     inline bool visible() const { return m_visible; }
     void setVisible(const bool visible);
 
@@ -132,6 +134,8 @@ public:
     inline const AuthProperty &getAuthProperty() const { return m_authProperty; }
     void setAuthType(const int type);
 
+    std::shared_ptr<User> json2User(const QString &userJson);
+
 signals:
     /* com.deepin.daemon.Accounts */
     void currentUserChanged(const std::shared_ptr<User>);
@@ -150,8 +154,8 @@ public slots:
     void addUser(const std::shared_ptr<User> user);
     void removeUser(const QString &path);
     void removeUser(const std::shared_ptr<User> user);
-    void updateCurrentUser(const QString &userJson);
-    void updateCurrentUser(const std::shared_ptr<User> user);
+    bool updateCurrentUser(const QString &userJson);
+    bool updateCurrentUser(const std::shared_ptr<User> user);
     void updateUserList(const QStringList &list);
     void updateLastLogoutUser(const uid_t uid);
     void updateLastLogoutUser(const std::shared_ptr<User> lastLogoutUser);
@@ -163,7 +167,7 @@ public slots:
     void updateSupportedEncryptionType(const QString &type);
     /* com.deepin.daemon.Authenticate.Session */
     void updateAuthState(const int type, const int state, const QString &message);
-    void updateFactorsInfo(const MFAInfoList &info);
+    void updateFactorsInfo(const MFAInfoList &infoList);
     void updateFuzzyMFA(const bool fuzzMFA);
     void updateMFAFlag(const bool MFAFlag);
     void updatePINLen(const int PINLen);
@@ -215,6 +219,7 @@ private:
     bool m_isLock = false;
     bool m_allowShowCustomUser;
     bool m_SEOpen; // 保存等保开启、关闭的状态
+    bool m_isUseWayland;
     int m_userListSize = 0;
     AppType m_appType;
     QList<std::shared_ptr<User>> m_userList;
