@@ -114,6 +114,7 @@ void ControlWidget::initKeyboardLayoutList()
     m_kbLayoutListView->setMinimumWidth(DDESESSIONCC::KEYBOARDLAYOUT_WIDTH);
     m_kbLayoutListView->setMaximumSize(DDESESSIONCC::KEYBOARDLAYOUT_WIDTH, DDESESSIONCC::LAYOUTBUTTON_HEIGHT * 7);
     m_kbLayoutListView->setFocusPolicy(Qt::NoFocus);
+    m_kbLayoutListView->setVisible(false);
 
     const QStringList languageList = language.split(";");
     if (!languageList.isEmpty())
@@ -132,14 +133,14 @@ void ControlWidget::initKeyboardLayoutList()
     m_arrowRectWidget->setMinimumWidth(DDESESSIONCC::KEYBOARDLAYOUT_WIDTH);
     m_arrowRectWidget->setMaximumSize(DDESESSIONCC::KEYBOARDLAYOUT_WIDTH, DDESESSIONCC::LAYOUTBUTTON_HEIGHT * 7);
     m_arrowRectWidget->setFocusPolicy(Qt::NoFocus);
+    m_arrowRectWidget->setBackgroundColor(QColor(235, 235, 235, int(0.05 * 255)));
+    m_arrowRectWidget->installEventFilter(this);
 
     QPalette pal = m_arrowRectWidget->palette();
     pal.setColor(DPalette::Inactive, DPalette::Base, QColor(235, 235, 235, int(0.05 * 255)));
     setPalette(pal);
 
-    m_arrowRectWidget->setContent(m_kbLayoutListView);
     connect(m_kbLayoutListView, &KBLayoutListView::itemClicked, this, &ControlWidget::onItemClicked);
-    connect(m_kbLayoutListView, &KBLayoutListView::sizeChange, this, &ControlWidget::resizeArrowWidget);
 }
 
 void ControlWidget::setVirtualKBVisible(bool visible)
@@ -310,6 +311,10 @@ void ControlWidget::addModule(module::BaseModuleInterface *module)
 
     connect(button, &FlotingButton::requestShowTips, this, [ = ] {
         if (trayModule->itemTipsWidget()) {
+            if (m_model->isUseWayland() && m_tipsWidget->parent() != topLevelWidget()) {
+                // 顶层对象的窗口是override级别，需要将其设置为弹窗的父对象，否则无法显示出来。
+                m_tipsWidget->setParent(topLevelWidget());
+            }
             m_tipsWidget->setContent(trayModule->itemTipsWidget());
             m_tipsWidget->show(mapToGlobal(button->pos()).x() + button->width() / 2,mapToGlobal(button->pos()).y());
         }
@@ -539,9 +544,17 @@ void ControlWidget::setKBLayoutVisible()
     if (!layoutButton)
         return;
 
-    // 算上三角形的高度
-    QPoint pos = mapToGlobal(layoutButton->pos()) - QPoint((m_kbLayoutListView->width() - layoutButton->width())/2, m_kbLayoutListView->height() + 10);
-    m_arrowRectWidget->setGeometry(QRect(pos, m_kbLayoutListView->size() + QSize(0, 10)));
+    if (!m_arrowRectWidget->getContent()) {
+        m_arrowRectWidget->setContent(m_kbLayoutListView);
+    }
+    if (m_model->isUseWayland() && m_arrowRectWidget->parent() != topLevelWidget()) {
+        // 顶层对象的窗口是override级别，需要将其设置为弹窗的父对象，否则无法显示出来。
+        m_arrowRectWidget->setParent(topLevelWidget());
+    }
+    m_arrowRectWidget->resize(m_kbLayoutListView->size() + QSize(0, 10));
+
+    QPoint pos = QPoint(mapToGlobal(layoutButton->pos()).x() + layoutButton->width() / 2, mapToGlobal(layoutButton->pos()).y());
+    m_arrowRectWidget->move(pos.x(), pos.y());
     m_arrowRectWidget->setVisible(!m_arrowRectWidget->isVisible());
 }
 
@@ -584,12 +597,6 @@ void ControlWidget::onItemClicked(const QString &str)
     m_curUser->setKeyboardLayout(str);
 }
 
-void ControlWidget::resizeArrowWidget()
-{
-    if (m_arrowRectWidget)
-        m_arrowRectWidget->setFixedSize(m_kbLayoutListView->size() + QSize(0, 10));
-}
-
 bool ControlWidget::eventFilter(QObject *watched, QEvent *event)
 {
 #ifndef SHENWEI_PLATFORM
@@ -612,6 +619,11 @@ bool ControlWidget::eventFilter(QObject *watched, QEvent *event)
             m_index = m_btnList.indexOf(btn);
         }
     }
+
+    if (watched == m_arrowRectWidget && event->type() == QEvent::Hide) {
+        emit notifyKeyboardLayoutHidden();
+    }
+
 #else
     Q_UNUSED(watched);
     Q_UNUSED(event);
