@@ -116,6 +116,7 @@ signals:
     void requestSwitchVirtualKB();
     void requestKeyboardLayout(const QPoint &pos);
     void requestShowModule(const QString &name);
+    void notifyKeyboardLayoutHidden();
 
 public slots:
     void addModule(dss::module::BaseModuleInterface *module);
@@ -130,7 +131,6 @@ public slots:
     void setKeyboardType(const QString& str);
     void setKeyboardList(const QStringList& str);
     void onItemClicked(const QString& str);
-    void resizeArrowWidget();
 
 protected:
     bool eventFilter(QObject *watched, QEvent *event) Q_DECL_OVERRIDE;
