@@ -67,10 +67,10 @@ FullscreenBackground::FullscreenBackground(SessionBaseModel *model, QWidget *par
     if (!m_model->isUseWayland()) {
         setWindowFlags(Qt::WindowStaysOnTopHint | Qt::X11BypassWindowManagerHint);
     } else {
-        setWindowFlags(windowFlags() | Qt::WindowStaysOnTopHint | Qt::FramelessWindowHint | Qt::Window);
+        setWindowFlags(windowFlags() | Qt::FramelessWindowHint | Qt::Window);
 
         setAttribute(Qt::WA_NativeWindow); // 创建窗口 handle
-        windowHandle()->setProperty("_d_dwayland_window-type", "standAlone"); // 禁止移动
+        windowHandle()->setProperty("_d_dwayland_window-type", "override"); // 禁止移动
     }
 #endif
     frameList.append(this);
@@ -119,7 +119,10 @@ void FullscreenBackground::updateBackground(const QString &path)
         // 动画播放完毕不再需要清晰的背景图片
         if (!m_fadeOutAniFinished && !(backgroundPath == path && contains(PIXMAP_TYPE_BACKGROUND))) {
             backgroundPath = path;
-            addPixmap(pixmapHandle(QPixmap(path)), PIXMAP_TYPE_BACKGROUND);
+
+            QPixmap pixmap;
+            loadPixmap(backgroundPath, pixmap);
+            addPixmap(pixmapHandle(pixmap), PIXMAP_TYPE_BACKGROUND);
         }
 
         // 需要播放动画的时候才更新模糊壁纸
@@ -143,7 +146,10 @@ void FullscreenBackground::updateBlurBackground(const QString &path)
 
             if (blurBackgroundPath != blurPath || !contains(PIXMAP_TYPE_BLUR_BACKGROUND)) {
                 blurBackgroundPath = blurPath;
-                addPixmap(pixmapHandle(QPixmap(blurPath)), PIXMAP_TYPE_BLUR_BACKGROUND);
+
+                QPixmap pixmap;
+                loadPixmap(blurBackgroundPath, pixmap);
+                addPixmap(pixmapHandle(pixmap), PIXMAP_TYPE_BLUR_BACKGROUND);
             }
 
             // 只播放一次动画，后续背景图片变更直接更新模糊壁纸即可
@@ -227,7 +233,7 @@ void FullscreenBackground::setIsHibernateMode()
 
 bool FullscreenBackground::isPicture(const QString &file)
 {
-    return QFile::exists(file) && QFile(file).size() && QImageReader(file).canRead();
+    return QFile::exists(file) && QFile(file).size() && checkPictureCanRead(file);
 }
 
 QString FullscreenBackground::getLocalFile(const QString &file)
@@ -301,11 +307,13 @@ void FullscreenBackground::enterEvent(QEvent *event)
     if (m_primaryShowFinished && m_enableEnterEvent && m_model->visible()) {
         m_content->show();
         emit contentVisibleChanged(true);
+        // 多屏情况下，此Frame晚于其它Frame显示出来时，可能处于未激活状态（特别是在wayland环境下比较明显）
+        activateWindow();
     }
 
     // 锁屏截图之后 activewindow 不是锁屏了，此时发现不是 activewindow 主动尝试激活
     if (!isActiveWindow() && m_content && m_content->isVisible())
-         tryActiveWindow();
+        tryActiveWindow();
 
     return QWidget::enterEvent(event);
 }
@@ -319,10 +327,16 @@ void FullscreenBackground::resizeEvent(QResizeEvent *event)
 {
     m_blackWidget->resize(size());
     m_content->resize(size());
-    if (isPicture(backgroundPath) && !contains(PIXMAP_TYPE_BACKGROUND))
-        addPixmap(pixmapHandle(QPixmap(backgroundPath)), PIXMAP_TYPE_BACKGROUND);
-    if (isPicture(blurBackgroundPath) && !contains(PIXMAP_TYPE_BLUR_BACKGROUND))
+    if (isPicture(backgroundPath) && !contains(PIXMAP_TYPE_BACKGROUND)) {
+        QPixmap pixmap;
+        loadPixmap(backgroundPath, pixmap);
+        addPixmap(pixmapHandle(pixmap), PIXMAP_TYPE_BACKGROUND);
+    }
+    if (isPicture(blurBackgroundPath) && !contains(PIXMAP_TYPE_BLUR_BACKGROUND)) {
+        QPixmap pixmap;
+        loadPixmap(blurBackgroundPath, pixmap);
         addPixmap(pixmapHandle(QPixmap(blurBackgroundPath)), PIXMAP_TYPE_BLUR_BACKGROUND);
+    }
 
     updatePixmap();
     QWidget::resizeEvent(event);
@@ -365,6 +379,7 @@ void FullscreenBackground::showEvent(QShowEvent *event)
     }
 
     updateGeometry();
+    raise();
     return QWidget::showEvent(event);
 }
 
