@@ -1,102 +1,218 @@
 <?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.1">
+<context>
+    <name>AuthFingerprint</name>
+    <message>
+        <source>Verify your fingerprint</source>
+        <translation>Vérifier votre empreinte digitale</translation>
+    </message>
+    <message>
+        <source>Verification successful</source>
+        <translation>Vérification réussie</translation>
+    </message>
+    <message numerus="yes">
+        <source>Verification failed, %n chances left</source>
+        <translation><numerusform>La vérification a échoué, il vous reste %n chance</numerusform><numerusform>La vérification a échoué, il vous reste %n chances</numerusform></translation>
+    </message>
+    <message>
+        <source>Verification failed, only one chance left</source>
+        <translation>La vérification a échoué, il ne vous reste plus qu&apos;un seul essai</translation>
+    </message>
+    <message>
+        <source>Fingerprint locked, use password please</source>
+        <translation>Empreinte digitale verrouillée, veuillez utiliser le mot de passe, s&apos;il vous plaît</translation>
+    </message>
+    <message numerus="yes">
+        <source>Please try again %n minute(s) later</source>
+        <translation><numerusform>Veuillez réessayer dans %n minute(s)</numerusform><numerusform>Veuillez réessayer dans %n minute(s)</numerusform></translation>
+    </message>
+</context>
+<context>
+    <name>AuthPassword</name>
+    <message>
+        <source>Verification successful</source>
+        <translation>Vérification réussie</translation>
+    </message>
+    <message numerus="yes">
+        <source>Verification failed, %n chances left</source>
+        <translation><numerusform>La vérification a échouée, il vous reste %n chance</numerusform><numerusform>La vérification a échouée, il vous reste %n chances</numerusform></translation>
+    </message>
+    <message>
+        <source>Verification failed, only one chance left</source>
+        <translation>La vérification a échoué, il ne vous reste plus qu&apos;un seul essai</translation>
+    </message>
+    <message>
+        <source>Wrong Password</source>
+        <translation>Mauvais mot de passe</translation>
+    </message>
+    <message>
+        <source>Password</source>
+        <translation>Mot de passe</translation>
+    </message>
+    <message numerus="yes">
+        <source>Please try again %n minute(s) later</source>
+        <translation><numerusform>Veuillez réessayer dans %n minute(s)</numerusform><numerusform>Veuillez réessayer dans %n minute(s)</numerusform></translation>
+    </message>
+</context>
+<context>
+    <name>AuthSingle</name>
+    <message>
+        <source>Please try again 1 minute later</source>
+        <translation>Veuillez réessayer dans 1 minute</translation>
+    </message>
+    <message numerus="yes">
+        <source>Please try again %n minutes later</source>
+        <translation><numerusform>Veuillez réessayer dans %n minute</numerusform><numerusform>Veuillez réessayer dans %n minutes</numerusform></translation>
+    </message>
+</context>
+<context>
+    <name>AuthUKey</name>
+    <message>
+        <source>Verification successful</source>
+        <translation>Vérification réussie</translation>
+    </message>
+    <message numerus="yes">
+        <source>Verification failed, %n chances left</source>
+        <translation><numerusform>La vérification a échouée, il vous reste %n chance</numerusform><numerusform>La vérification a échouée, il vous reste %n chances</numerusform></translation>
+    </message>
+    <message>
+        <source>Verification failed, only one chance left</source>
+        <translation>La vérification a échoué, il ne vous reste plus qu&apos;un seul essai</translation>
+    </message>
+    <message>
+        <source>Wrong PIN</source>
+        <translation>Mauvais code PIN</translation>
+    </message>
+    <message>
+        <source>UKey is required</source>
+        <translation>UKey est requis</translation>
+    </message>
+    <message>
+        <source>Enter your PIN</source>
+        <translation>Entrez votre code PIN</translation>
+    </message>
+    <message numerus="yes">
+        <source>Please try again %n minute(s) later</source>
+        <translation><numerusform>Veuillez réessayer dans %n minute(s)</numerusform><numerusform>Veuillez réessayer dans %n minute(s)</numerusform></translation>
+    </message>
+</context>
+<context>
+    <name>AuthenticationModule</name>
+    <message>
+        <source>Verification successful</source>
+        <translation>Vérification réussie</translation>
+    </message>
+    <message numerus="yes">
+        <source>Verification failed, %n chances left</source>
+        <translation><numerusform>La vérification a échoué, il vous reste %n essais</numerusform><numerusform>La vérification a échoué,  il vous reste %n essais</numerusform></translation>
+    </message>
+    <message>
+        <source>Verification failed, only one chance left</source>
+        <translation>La vérification a échoué, il ne vous reste plus qu&apos;un seul essai</translation>
+    </message>
+    <message>
+        <source>Wrong Password</source>
+        <translation>Mauvais mot de passe</translation>
+    </message>
+    <message>
+        <source>Wrong PIN</source>
+        <translation>Mauvais code PIN</translation>
+    </message>
+    <message>
+        <source>UKey is required</source>
+        <translation>UKey est requis</translation>
+    </message>
+    <message>
+        <source>Verify your fingerprint</source>
+        <translation>Vérifier votre empreinte digitale</translation>
+    </message>
+    <message>
+        <source>Password</source>
+        <translation>Mot de passe</translation>
+    </message>
+    <message>
+        <source>Enter your PIN</source>
+        <translation>Entrez votre code PIN</translation>
+    </message>
+    <message>
+        <source>Fingerprint locked, use password please</source>
+        <translation>Empreinte digitale verrouillée, veuillez utiliser le mot de passe, s&apos;il vous plaît</translation>
+    </message>
+    <message>
+        <source>Please try again 1 minute later</source>
+        <translation>Veuillez réessayer dans 1 minute</translation>
+    </message>
+    <message numerus="yes">
+        <source>Please try again %n minutes later</source>
+        <translation><numerusform>Veuillez réessayer dans %n minute</numerusform><numerusform>Veuillez réessayer dans %n minutes</numerusform></translation>
+    </message>
+</context>
 <context>
     <name>ContentWidget</name>
     <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="357"/>
         <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
         <translation>Les programmes empêchent l&apos;ordinateur de s&apos;éteindre, et le forcer à arrêter peut entraîner une perte de données.</translation>
     </message>
     <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="358"/>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="363"/>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="367"/>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="371"/>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="375"/>
         <source>To close the program, click Cancel, and then close the program.</source>
         <translation>Pour fermer le programme, cliquer sur Annuler, puis fermer le programme.</translation>
     </message>
     <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="362"/>
         <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
         <translation>Les programmes empêchent l&apos;ordinateur de redémarrer et forcer le redémarrage peut entraîner une perte de données.</translation>
     </message>
     <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="366"/>
         <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
         <translation>Les programmes empêchent l&apos;ordinateur de se mettre en veille, et forcer la mise en veille peut entraîner une perte de données.</translation>
     </message>
     <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="370"/>
         <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
         <translation>Les programmes empêchent l&apos;ordinateur de se mettre en veille prolongée, et l&apos;obliger à se mettre en veille prolongée peut entraîner une perte de données.</translation>
     </message>
     <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="374"/>
         <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
         <translation>Les programmes empêchent l&apos;ordinateur de se déconnecter et le fait de forcer la déconnexion peut entraîner une perte de données.</translation>
     </message>
     <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="391"/>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="435"/>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="460"/>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="614"/>
         <source>Shut down</source>
         <translation>Arrêter</translation>
     </message>
     <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="394"/>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="437"/>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="463"/>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="617"/>
         <source>Reboot</source>
         <translation>Redémarrer</translation>
     </message>
     <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="397"/>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="620"/>
         <source>Suspend</source>
         <translation>Mise en veille </translation>
     </message>
     <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="399"/>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="623"/>
         <source>Hibernate</source>
         <translation>Mise en veille prolongée</translation>
     </message>
     <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="401"/>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="466"/>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="629"/>
         <source>Log out</source>
         <translation>Déconnexion</translation>
     </message>
     <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="461"/>
         <source>Are you sure you want to shut down?</source>
         <translation>Êtes-vous sûr de vouloir éteindre ?</translation>
     </message>
     <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="464"/>
         <source>Are you sure you want to reboot?</source>
         <translation>Êtes-vous sûr de vouloir redémarrer ?</translation>
     </message>
     <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="467"/>
         <source>Are you sure you want to log out?</source>
         <translation>Êtes-vous sûr de vouloir vous déconnecter ?</translation>
     </message>
     <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="626"/>
         <source>Lock</source>
         <translation>Verrouiller</translation>
     </message>
     <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="632"/>
         <source>Switch user</source>
         <translation>Changer d&apos;utilisateur</translation>
     </message>
     <message>
-        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="637"/>
         <source>Switch system</source>
         <translation>Changer de système </translation>
     </message>
@@ -104,21 +220,17 @@
 <context>
     <name>GreeterWorkek</name>
     <message>
-        <location filename="../src/lightdm-deepin-greeter/greeterworkek.cpp" line="329"/>
-        <source>Wrong Password</source>
-        <translation>Mauvais mot de passe </translation>
+        <source>Wrong account</source>
+        <translation>Mauvais compte</translation>
     </message>
     <message>
-        <location filename="../src/lightdm-deepin-greeter/greeterworkek.cpp" line="333"/>
-        <source>The account or password is not correct. Please enter again.</source>
-        <translation>Le compte ou le mot de passe n&apos;est pas correct. Veuillez l&apos;entrer à nouveau.</translation>
+        <source>Wrong Password</source>
+        <translation>Mauvais mot de passe </translation>
     </message>
 </context>
 <context>
     <name>InhibitWarnView</name>
     <message>
-        <location filename="../src/dde-shutdown/view/inhibitwarnview.cpp" line="90"/>
-        <location filename="../src/widgets/inhibitwarnview.cpp" line="90"/>
         <source>Cancel</source>
         <translation>Annuler</translation>
     </message>
@@ -126,12 +238,10 @@
 <context>
     <name>LockContent</name>
     <message>
-        <location filename="../src/session-widgets/lockcontent.cpp" line="405"/>
         <source>Lock Screen</source>
         <translation>Écran verrouillé</translation>
     </message>
     <message>
-        <location filename="../src/session-widgets/lockcontent.cpp" line="409"/>
         <source>Failed to lock screen</source>
         <translation>Impossible de verrouiller l&apos;écran</translation>
     </message>
@@ -139,38 +249,25 @@
 <context>
     <name>LockWorker</name>
     <message>
-        <location filename="../src/dde-lock/lockworker.cpp" line="291"/>
         <source>Fingerprint verification timed out, please enter your password manually</source>
         <translation>Aucune correspondance trouvée pour cette empreinte digitale, veuillez entrer votre mot de passe manuellement.</translation>
     </message>
     <message>
-        <location filename="../src/dde-lock/lockworker.cpp" line="309"/>
         <source>Failed to match fingerprint</source>
         <translation>Impossible de faire correspondre l&apos;empreinte digitale.</translation>
     </message>
-    <message>
-        <location filename="../src/dde-lock/lockworker.cpp" line="339"/>
-        <source>Wrong Password</source>
-        <translation>Mauvais mot de passe </translation>
-    </message>
 </context>
 <context>
     <name>MultiUsersWarningView</name>
     <message>
-        <location filename="../src/dde-shutdown/view/multiuserswarningview.cpp" line="45"/>
-        <location filename="../src/widgets/multiuserswarningview.cpp" line="45"/>
         <source>Cancel</source>
         <translation>Annuler</translation>
     </message>
     <message>
-        <location filename="../src/dde-shutdown/view/multiuserswarningview.cpp" line="130"/>
-        <location filename="../src/widgets/multiuserswarningview.cpp" line="133"/>
         <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
         <translation>Les utilisateurs ci-dessus sont toujours connectés, des données seront perdues si vous éteignez l&apos;ordinateur, êtes-vous sûr de vouloir poursuivre?</translation>
     </message>
     <message>
-        <location filename="../src/dde-shutdown/view/multiuserswarningview.cpp" line="134"/>
-        <location filename="../src/widgets/multiuserswarningview.cpp" line="137"/>
         <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
         <translation>Les utilisateurs ci-dessus sont toujours connectés, des données seront perdues si vous redémarrez l&apos;ordinateur, êtes-vous sûr de vouloir poursuivre?</translation>
     </message>
@@ -178,45 +275,34 @@
 <context>
     <name>ShutdownWidget</name>
     <message>
-        <location filename="../src/widgets/shutdownwidget.cpp" line="30"/>
         <source>Shut down</source>
         <translation>Arrêter</translation>
     </message>
     <message>
-        <location filename="../src/widgets/shutdownwidget.cpp" line="31"/>
-        <location filename="../src/widgets/shutdownwidget.cpp" line="172"/>
         <source>Reboot</source>
         <translation>Redémarrer</translation>
     </message>
     <message>
-        <location filename="../src/widgets/shutdownwidget.cpp" line="32"/>
-        <location filename="../src/widgets/shutdownwidget.cpp" line="178"/>
         <source>Suspend</source>
         <translation>Mise en veille </translation>
     </message>
     <message>
-        <location filename="../src/widgets/shutdownwidget.cpp" line="33"/>
-        <location filename="../src/widgets/shutdownwidget.cpp" line="184"/>
         <source>Hibernate</source>
         <translation>Mise en veille prolongée</translation>
     </message>
     <message>
-        <location filename="../src/widgets/shutdownwidget.cpp" line="190"/>
         <source>Lock</source>
         <translation>Fermer à clé</translation>
     </message>
     <message>
-        <location filename="../src/widgets/shutdownwidget.cpp" line="196"/>
         <source>Log out</source>
         <translation>Se déconnecter</translation>
     </message>
     <message>
-        <location filename="../src/widgets/shutdownwidget.cpp" line="202"/>
         <source>Switch user</source>
         <translation>Changer d&apos;utilisateur</translation>
     </message>
     <message>
-        <location filename="../src/widgets/shutdownwidget.cpp" line="210"/>
         <source>Switch system</source>
         <translation>Système de commutation</translation>
     </message>
@@ -224,8 +310,6 @@
 <context>
     <name>SystemMonitor</name>
     <message>
-        <location filename="../src/dde-shutdown/view/systemmonitor.cpp" line="45"/>
-        <location filename="../src/widgets/systemmonitor.cpp" line="45"/>
         <source>Start system monitor</source>
         <translation>Démarrer le moniteur système</translation>
     </message>
@@ -233,109 +317,77 @@
 <context>
     <name>UserLoginWidget</name>
     <message>
-        <location filename="../src/session-widgets/userloginwidget.cpp" line="193"/>
-        <source>Password</source>
-        <translation>Mot de passe</translation>
-    </message>
-    <message>
-        <location filename="../src/session-widgets/userloginwidget.cpp" line="197"/>
         <source>Account</source>
         <translation>Compte</translation>
     </message>
     <message>
-        <location filename="../src/session-widgets/userloginwidget.cpp" line="239"/>
-        <source>Please enter the account</source>
-        <translation>Veuillez saisir le compte</translation>
-    </message>
-    <message>
-        <location filename="../src/session-widgets/userloginwidget.cpp" line="246"/>
-        <source>Please enter the password</source>
-        <translation>Entrer le mot de passe, s&apos;il vous plaît </translation>
+        <source>Verify your fingerprint</source>
+        <translation>Vérifier votre empreinte digitale</translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/session-widgets/userloginwidget.cpp" line="338"/>
-        <source>Please try again %n minute(s) later</source>
-        <translation><numerusform>Veuillez réessayer dans %n minute(s) plus tard</numerusform><numerusform>Veuillez réessayer dans %n minute(s) plus tard</numerusform></translation>
+        <source>Your password will expire in %n days, please change it timely</source>
+        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
+    </message>
+    <message>
+        <source>Password expired, please change</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
     <name>WarningContent</name>
     <message>
-        <location filename="../src/widgets/warningcontent.cpp" line="149"/>
         <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
         <translation>Les programmes empêchent l&apos;ordinateur de s&apos;éteindre et forcer l&apos;arrêt peut entraîner une perte de données.</translation>
     </message>
     <message>
-        <location filename="../src/widgets/warningcontent.cpp" line="150"/>
-        <location filename="../src/widgets/warningcontent.cpp" line="155"/>
-        <location filename="../src/widgets/warningcontent.cpp" line="159"/>
-        <location filename="../src/widgets/warningcontent.cpp" line="163"/>
-        <location filename="../src/widgets/warningcontent.cpp" line="167"/>
         <source>To close the program, click Cancel, and then close the program.</source>
-        <translation>Pour fermer le programme, cliquer sur Annuler, puis fermer le programme.</translation>
+        <translation>Pour fermer le programme, cliquez sur Annuler, puis fermez le programme.</translation>
     </message>
     <message>
-        <location filename="../src/widgets/warningcontent.cpp" line="154"/>
         <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
         <translation>Les programmes empêchent l&apos;ordinateur de redémarrer et forcer le redémarrage peut entraîner une perte de données.</translation>
     </message>
     <message>
-        <location filename="../src/widgets/warningcontent.cpp" line="158"/>
         <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
         <translation>Les programmes empêchent l&apos;ordinateur de se suspendre et forcer la suspension peut entraîner une perte de données.</translation>
     </message>
     <message>
-        <location filename="../src/widgets/warningcontent.cpp" line="162"/>
         <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
         <translation>Les programmes empêchent l&apos;ordinateur de mettre en veille prolongée et forcer la mise en veille prolongée peut entraîner une perte de données.</translation>
     </message>
     <message>
-        <location filename="../src/widgets/warningcontent.cpp" line="166"/>
         <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
         <translation>Les programmes empêchent l&apos;ordinateur de se déconnecter et forcer la déconnexion peut entraîner une perte de données.</translation>
     </message>
     <message>
-        <location filename="../src/widgets/warningcontent.cpp" line="182"/>
-        <location filename="../src/widgets/warningcontent.cpp" line="235"/>
-        <location filename="../src/widgets/warningcontent.cpp" line="267"/>
         <source>Shut down</source>
-        <translation>Arrêter</translation>
+        <translation>Eteindre</translation>
     </message>
     <message>
-        <location filename="../src/widgets/warningcontent.cpp" line="185"/>
-        <location filename="../src/widgets/warningcontent.cpp" line="237"/>
-        <location filename="../src/widgets/warningcontent.cpp" line="270"/>
         <source>Reboot</source>
         <translation>Redémarrer</translation>
     </message>
     <message>
-        <location filename="../src/widgets/warningcontent.cpp" line="188"/>
         <source>Suspend</source>
         <translation>Suspendre</translation>
     </message>
     <message>
-        <location filename="../src/widgets/warningcontent.cpp" line="190"/>
         <source>Hibernate</source>
         <translation>Mise en veille prolongée</translation>
     </message>
     <message>
-        <location filename="../src/widgets/warningcontent.cpp" line="192"/>
-        <location filename="../src/widgets/warningcontent.cpp" line="273"/>
         <source>Log out</source>
         <translation>Se déconnecter</translation>
     </message>
     <message>
-        <location filename="../src/widgets/warningcontent.cpp" line="268"/>
         <source>Are you sure you want to shut down?</source>
         <translation>Êtes-vous sûr de vouloir arrêter ?</translation>
     </message>
     <message>
-        <location filename="../src/widgets/warningcontent.cpp" line="271"/>
         <source>Are you sure you want to reboot?</source>
         <translation>Êtes-vous sûr de vouloir redémarrer ?</translation>
     </message>
     <message>
-        <location filename="../src/widgets/warningcontent.cpp" line="274"/>
         <source>Are you sure you want to log out?</source>
         <translation>Êtes-vous sûr de vouloir vous déconnecter ?</translation>
     </message>
